#
# spec file for package python-typing_extensions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-typing_extensions%{psuffix}
Version:        4.12.2
Release:        1.1
Summary:        Backported and Experimental Type Hints for Python 3.8+
License:        Python-2.0
URL:            https://github.com/python/typing_extensions
Source0:        https://files.pythonhosted.org/packages/source/t/typing_extensions/typing_extensions-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flit-core >= 3.4 with %python-flit-core < 4}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-typing-extensions = %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module testsuite}
%endif
%python_subpackages

%description
The typing_extensions module serves two related purposes:

  * Enable use of new type system features on older Python versions.
    For example, typing.TypeGuard is new in Python 3.10, but
    typing_extensions allows users on previous Python versions to use
    it too.
  * Enable experimentation with new type system PEPs before they are
    accepted and added to the typing module.

New features may be added to typing_extensions as soon as they are
specified in a PEP that has been added to the python/peps repository.
If the PEP is accepted, the feature will then be added to typing for
the next CPython release. No typing PEP has been rejected so far, so
we haven't yet figured out how to deal with that possibility.

Starting with version 4.0.0, typing_extensions uses Semantic Versioning.
The major version is incremented for all backwards-incompatible changes.
Therefore, it's safe to depend on typing_extensions like this:
typing_extensions >=x.y, <(x+1),
where x.y is the first version that includes all features you need.

typing_extensions supports Python versions 3.7 and higher.
In the future, support for older Python versions will be dropped some time
after that version reaches end of life.

%prep
%autosetup -p1 -n typing_extensions-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
pushd src
%pyunittest -v test_typing_extensions
popd
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/typing_extensions.py*
%pycache_only %{python_sitelib}/__pycache__/typing_extensions*
%{python_sitelib}/typing_extensions-%{version}*-info
%endif

%changelog
* Sat Jun  8 2024 Dirk Müller <dmueller@suse.com>
- update to 4.12.2:
  * Fix regression in v4.12.0 where specialization of certain
  * generics with an overridden `__eq__` method would raise
    errors.
  * Fix tests so they pass on 3.13.0b2
  * Preliminary changes for compatibility with the draft
    implementation of PEP 649 in Python 3.14.
  * Fix regression in v4.12.0 where nested `Annotated` types
    would cause `TypeError` to be raised if the nested
    `Annotated` type had unhashable metadata.
  * Fix incorrect behaviour of `typing_extensions.ParamSpec` on
    Python 3.8 and 3.9 that meant that
    `isinstance(typing_extensions.ParamSpec("P"),
    typing.TypeVar)` would have a different result in some
    situations depending on whether or not a profiling
    function had been set using `sys.setprofile`.
  * This release focuses on compatibility with the upcoming
    release of Python 3.13. Most changes are related to the
    implementation of type parameter defaults (PEP 696).
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 4.11.0:
  * Fix tests on Python 3.13.0a5. Patch by Jelle Zijlstra.
  * Fix the runtime behavior of type parameters with defaults
  * Fix minor discrepancy between error messages produced by
    `typing` and `typing_extensions` on Python 3.10.
  * When `include_extra=False`, `get_type_hints()` now strips
    `ReadOnly` from the annotation.
* Wed Feb 28 2024 Adrian Schröter <adrian@suse.de>
- update to 4.10.0:
  This feature release adds support for PEP 728 (TypedDict with extra
  items) and PEP 742 (``TypeIs``).
  - Add support for PEP 728, supporting the `closed` keyword argument and the
    special `__extra_items__` key for TypedDict. Patch by Zixuan James Li.
  - Add support for PEP 742, adding `typing_extensions.TypeIs`. Patch
    by Jelle Zijlstra.
  - Drop runtime error when a read-only `TypedDict` item overrides a mutable
    one. Type checkers should still flag this as an error. Patch by Jelle
    Zijlstra.
  - Speedup `issubclass()` checks against simple runtime-checkable protocols by
    around 6%% (backporting https://github.com/python/cpython/pull/112717, by Alex
    Waygood).
  - Fix a regression in the implementation of protocols where `typing.Protocol`
    classes that were not marked as `@runtime_checkable` would be unnecessarily
    introspected, potentially causing exceptions to be raised if the protocol had
    problematic members. Patch by Alex Waygood, backporting
    https://github.com/python/cpython/pull/113401.
- obsoletes backport-recent-implementation-of-protocol.patch
* Thu Feb  8 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add backport-recent-implementation-of-protocol.patch upstream patch
  gh#python/typing_extensions@004b893ddce2
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 4.9.0:
  * This feature release adds `typing_extensions.ReadOnly`, as
    specified by PEP 705, and makes various other improvements,
    especially to `@typing_extensions.deprecated()`.
  * Add support for PEP 705, adding `typing_extensions.ReadOnly`.
  * All parameters on `NewType.__call__` are now positional-only.
    This means that the signature of
    `typing_extensions.NewType.__call__` now exactly matches the
  * signature of `typing.NewType.__call__`.
  * Fix bug with using `@deprecated` on a mixin class.
  * Exclude `__match_args__` from `Protocol` members.
  * When creating a `typing_extensions.NamedTuple` class, ensure
    `__set_name__` is called on all objects that define
    `__set_name__` and exist in the values of the `NamedTuple`
    class's class dictionary.
* Thu Oct 19 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 4.8.0:
  - Add typing_extensions.Doc, as proposed by PEP 727
  - Drop support for Python 3.7 (including PyPy-3.7)
  - Fix bug where get_original_bases() would return incorrect
    results when called on a concrete subclass of a generic class
  - Fix bug where ParamSpec(default=...) would raise a TypeError
    on Python versions <3.11
* Sun Aug 13 2023 Sebastian Wagner <sebix@sebix.at>
- update to version 4.7.1:
  - Fix support for `TypedDict`, `NamedTuple` and `is_protocol` on PyPy-3.7 and
  PyPy-3.8. Patch by Alex Waygood. Note that PyPy-3.7 and PyPy-3.8 are unsupported
  by the PyPy project. The next feature release of typing-extensions will
  drop support for PyPy-3.7 and may also drop support for PyPy-3.8.
- update to version 4.7.0:
  - This is expected to be the last feature release supporting Python 3.7,
  which reaches its end of life on June 27, 2023. Version 4.8.0 will support
  only Python 3.8.0 and up.
  - Fix bug where a `typing_extensions.Protocol` class that had one or more
  non-callable members would raise `TypeError` when `issubclass()`
  was called against it, even if it defined a custom `__subclasshook__`
  method. The correct behaviour -- which has now been restored -- is not to
  raise `TypeError` in these situations if a custom `__subclasshook__` method
  is defined. Patch by Alex Waygood (backporting
  https://github.com/python/cpython/pull/105976).
- update to version 4.7.0rc1:
  - Add `typing_extensions.get_protocol_members` and
  `typing_extensions.is_protocol` (backport of CPython PR #104878).
  Patch by Jelle Zijlstra.
  - `typing_extensions` now re-exports all names in the standard library's
  `typing` module, except the deprecated `ByteString`. Patch by Jelle
  Zijlstra.
  - Due to changes in the implementation of `typing_extensions.Protocol`,
  `typing.runtime_checkable` can now be used on `typing_extensions.Protocol`
  (previously, users had to use `typing_extensions.runtime_checkable` if they
  were using `typing_extensions.Protocol`).
  - Align the implementation of `TypedDict` with the implementation in the
  standard library on Python 3.9 and higher.
  `typing_extensions.TypedDict` is now a function instead of a class. The
  private functions `_check_fails`, `_dict_new`, and `_typeddict_new`
  have been removed. `is_typeddict` now returns `False` when called with
  `TypedDict` itself as the argument. Patch by Jelle Zijlstra.
  - Declare support for Python 3.12. Patch by Jelle Zijlstra.
  - Fix tests on Python 3.13, which removes support for creating
  `TypedDict` classes through the keyword-argument syntax. Patch by
  Jelle Zijlstra.
  - Fix a regression introduced in v4.6.3 that meant that
  ``issubclass(object, typing_extensions.Protocol)`` would erroneously raise
  ``TypeError``. Patch by Alex Waygood (backporting the CPython PR
  https://github.com/python/cpython/pull/105239).
  - Allow `Protocol` classes to inherit from `typing_extensions.Buffer` or
  `collections.abc.Buffer`. Patch by Alex Waygood (backporting
  https://github.com/python/cpython/pull/104827, by Jelle Zijlstra).
  - Allow classes to inherit from both `typing.Protocol` and `typing_extensions.Protocol`
  simultaneously. Since v4.6.0, this caused `TypeError` to be raised due to a
  metaclass conflict. Patch by Alex Waygood.
  - Backport several deprecations from CPython relating to unusual ways to
  create `TypedDict`s and `NamedTuple`s. CPython PRs #105609 and #105780
  by Alex Waygood; `typing_extensions` backport by Jelle Zijlstra.
  - Creating a `NamedTuple` using the functional syntax with keyword arguments
    (`NT = NamedTuple("NT", a=int)`) is now deprecated.
  - Creating a `NamedTuple` with zero fields using the syntax `NT = NamedTuple("NT")`
    or `NT = NamedTuple("NT", None)` is now deprecated.
  - Creating a `TypedDict` with zero fields using the syntax `TD = TypedDict("TD")`
    or `TD = TypedDict("TD", None)` is now deprecated.
  - Fix bug on Python 3.7 where a protocol `X` that had a member `a` would not be
  considered an implicit subclass of an unrelated protocol `Y` that only has a
  member `a`. Where the members of `X` are a superset of the members of `Y`,
  `X` should always be considered a subclass of `Y` iff `Y` is a
  runtime-checkable protocol that only has callable members. Patch by Alex
  Waygood (backporting CPython PR
  https://github.com/python/cpython/pull/105835).
- update to version 4.6.3 (June 1, 2023)
  - Fix a regression introduced in v4.6.0 in the implementation of
  runtime-checkable protocols. The regression meant
  that doing `class Foo(X, typing_extensions.Protocol)`, where `X` was a class that
  had `abc.ABCMeta` as its metaclass, would then cause subsequent
  `isinstance(1, X)` calls to erroneously raise `TypeError`. Patch by
  Alex Waygood (backporting the CPython PR
  https://github.com/python/cpython/pull/105152).
  - Sync the repository's LICENSE file with that of CPython.
  `typing_extensions` is distributed under the same license as
  CPython itself.
  - Skip a problematic test on Python 3.12.0b1. The test fails on 3.12.0b1 due to
  a bug in CPython, which will be fixed in 3.12.0b2. The
  `typing_extensions` test suite now passes on 3.12.0b1.
- update to version 4.6.2:
  - Fix use of `@deprecated` on classes with `__new__` but no `__init__`.
  Patch by Jelle Zijlstra.
  - Fix regression in version 4.6.1 where comparing a generic class against a
  runtime-checkable protocol using `isinstance()` would cause `AttributeError`
  to be raised if using Python 3.7.
- update to version 4.6.1:
  - Change deprecated `@runtime` to formal API `@runtime_checkable` in the error
  message. Patch by Xuehai Pan.
  - Fix regression in 4.6.0 where attempting to define a `Protocol` that was
  generic over a `ParamSpec` or a `TypeVarTuple` would cause `TypeError` to be
  raised. Patch by Alex Waygood.
- update to version 4.6.0:
  - `typing_extensions` is now documented at
  https://typing-extensions.readthedocs.io/en/latest/. Patch by Jelle Zijlstra.
  - Add `typing_extensions.Buffer`, a marker class for buffer types, as proposed
  by PEP 688. Equivalent to `collections.abc.Buffer` in Python 3.12. Patch by
  Jelle Zijlstra.
  - Backport two CPython PRs fixing various issues with `typing.Literal`:
  https://github.com/python/cpython/pull/23294 and
  https://github.com/python/cpython/pull/23383. Both CPython PRs were
  originally by Yurii Karabas, and both were backported to Python >=3.9.1, but
  no earlier. Patch by Alex Waygood.
  A side effect of one of the changes is that equality comparisons of `Literal`
  objects will now raise a `TypeError` if one of the `Literal` objects being
  compared has a mutable parameter. (Using mutable parameters with `Literal` is
  not supported by PEP 586 or by any major static type checkers.)
  - `Literal` is now reimplemented on all Python versions <= 3.10.0. The
  `typing_extensions` version does not suffer from the bug that was fixed in
  https://github.com/python/cpython/pull/29334. (The CPython bugfix was
  backported to CPython 3.10.1 and 3.9.8, but no earlier.)
  - Backport [CPython PR 26067](https://github.com/python/cpython/pull/26067)
  (originally by Yurii Karabas), ensuring that `isinstance()` calls on
  protocols raise `TypeError` when the protocol is not decorated with
  `@runtime_checkable`. Patch by Alex Waygood.
  - Backport several significant performance improvements to runtime-checkable
  protocols that have been made in Python 3.12 (see
  https://github.com/python/cpython/issues/74690 for details). Patch by Alex
  Waygood.
  A side effect of one of the performance improvements is that the members of
  a runtime-checkable protocol are now considered “frozen” at runtime as soon
  as the class has been created. Monkey-patching attributes onto a
  runtime-checkable protocol will still work, but will have no impact on
  `isinstance()` checks comparing objects to the protocol. See
  ["What's New in Python 3.12"](https://docs.python.org/3.12/whatsnew/3.12.html#typing)
  for more details.
  - `isinstance()` checks against runtime-checkable protocols now use
  `inspect.getattr_static()` rather than `hasattr()` to lookup whether
  attributes exist (backporting https://github.com/python/cpython/pull/103034).
  This means that descriptors and `__getattr__` methods are no longer
  unexpectedly evaluated during `isinstance()` checks against runtime-checkable
  protocols. However, it may also mean that some objects which used to be
  considered instances of a runtime-checkable protocol on older versions of
  `typing_extensions` may no longer be considered instances of that protocol
  using the new release, and vice versa. Most users are unlikely to be affected
  by this change. Patch by Alex Waygood.
  - Backport the ability to define `__init__` methods on Protocol classes, a
  change made in Python 3.11 (originally implemented in
  https://github.com/python/cpython/pull/31628 by Adrian Garcia Badaracco).
  Patch by Alex Waygood.
  - Speedup `isinstance(3, typing_extensions.SupportsIndex)` by >10x on Python
  <3.12. Patch by Alex Waygood.
  - Add `typing_extensions` versions of `SupportsInt`, `SupportsFloat`,
  `SupportsComplex`, `SupportsBytes`, `SupportsAbs` and `SupportsRound`. These
  have the same semantics as the versions from the `typing` module, but
  `isinstance()` checks against the `typing_extensions` versions are >10x faster
  at runtime on Python <3.12. Patch by Alex Waygood.
  - Add `__orig_bases__` to non-generic TypedDicts, call-based TypedDicts, and
  call-based NamedTuples. Other TypedDicts and NamedTuples already had the attribute.
  Patch by Adrian Garcia Badaracco.
  - Add `typing_extensions.get_original_bases`, a backport of
  [`types.get_original_bases`](https://docs.python.org/3.12/library/types.html#types.get_original_bases),
  introduced in Python 3.12 (CPython PR
  https://github.com/python/cpython/pull/101827, originally by James
  Hilton-Balfe). Patch by Alex Waygood.
  This function should always produce correct results when called on classes
  constructed using features from `typing_extensions`. However, it may
  produce incorrect results when called on some `NamedTuple` or `TypedDict`
  classes that use `typing.{NamedTuple,TypedDict}` on Python <=3.11.
  - Constructing a call-based `TypedDict` using keyword arguments for the fields
  now causes a `DeprecationWarning` to be emitted. This matches the behaviour
  of `typing.TypedDict` on 3.11 and 3.12.
  - Backport the implementation of `NewType` from 3.10 (where it is implemented
  as a class rather than a function). This allows user-defined `NewType`s to be
  pickled. Patch by Alex Waygood.
  - Fix tests and import on Python 3.12, where `typing.TypeVar` can no longer be
  subclassed. Patch by Jelle Zijlstra.
  - Add `typing_extensions.TypeAliasType`, a backport of `typing.TypeAliasType`
  from PEP 695. Patch by Jelle Zijlstra.
  - Backport changes to the repr of `typing.Unpack` that were made in order to
  implement [PEP 692](https://peps.python.org/pep-0692/) (backport of
  https://github.com/python/cpython/pull/104048). Patch by Alex Waygood.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Feb 23 2023 Adrian Schröter <adrian@suse.de>
- update to version 4.5.0
  Details can be found here: https://pypi.org/project/typing-extensions/4.5.0/
- obsoletes _typed_dict_test_helper.py hack
* Sun Nov 20 2022 Ben Greiner <code@bnavigator.de>
- Back to multibuild: remove python-testsuite from buildcycle,
  because of setuptools_scm closing it at the other end.
* Mon Oct 24 2022 Ben Greiner <code@bnavigator.de>
- Clean specfile from old cruft.
- Requires Python 3.7+
- Fix testsuite: Must test as module; don't need multibuild.
- Update Summary and Description
* Tue Oct 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 4.4.0
  * Add `typing_extensions.Any` a backport of python 3.11's Any class which is
    subclassable at runtime. (backport from python/cpython#31841, by Shantanu
    and Jelle Zijlstra). Patch by James Hilton-Balfe (@Gobot1234).
  * Add initial support for TypeVarLike `default` parameter, PEP 696.
    Patch by Marc Mueller (@cdce8p).
  * Runtime support for PEP 698, adding `typing_extensions.override`. Patch by
    Jelle Zijlstra.
  * Add the `infer_variance` parameter to `TypeVar`, as specified in PEP 695.
    Patch by Jelle Zijlstra.
* Mon Sep  5 2022 John Vandenberg <jayvdb@gmail.com>
- Add _typed_dict_test_helper.py missing from PyPI release
- Update to v4.3.0
  * Add typing_extensions.NamedTuple, allowing for generic NamedTuples
    on Python <3.11 (backport from python/cpython#92027, by Serhiy Storchaka)
  * Adjust typing_extensions.TypedDict to allow for generic TypedDicts
    on Python <3.11 (backport from python/cpython#27663, by Samodya Abey)
* Wed Apr 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 4.2.0
  * Re-export `typing.Unpack` and `typing.TypeVarTuple` on Python 3.11.
  * Add `ParamSpecArgs` and `ParamSpecKwargs` to `__all__`.
  * Improve "accepts only single type" error messages.
  * Improve the distributed package. Patch by Marc Mueller (@cdce8p).
  * Update `typing_extensions.dataclass_transform` to rename the
    `field_descriptors` parameter to `field_specifiers` and accept
    arbitrary keyword arguments.
  * Add `typing_extensions.get_overloads` and
    `typing_extensions.clear_overloads`, and add registry support to
    `typing_extensions.overload`. Backport from python/cpython#89263.
  * Add `typing_extensions.assert_type`. Backport from bpo-46480.
  * Drop support for Python 3.6. Original patch by Adam Turner (@AA-Turner).
- from version 4.1.1
  * Fix importing `typing_extensions` on Python 3.7.0 and 3.7.1. Original
    patch by Nikita Sobolev (@sobolevn).
- from version 4.1.0
  * Runtime support for PEP 646, adding `typing_extensions.TypeVarTuple`
    and `typing_extensions.Unpack`.
  * Add interaction of `Required` and `NotRequired` with `__required_keys__`,
    `__optional_keys__` and `get_type_hints()`. Patch by David Cabot (@d-k-bo).
  * Runtime support for PEP 675 and `typing_extensions.LiteralString`.
  * Add `Never` and `assert_never`. Backport from bpo-46475.
  * `ParamSpec` args and kwargs are now equal to themselves. Backport from
    bpo-46676. Patch by Gregory Beauregard (@GBeauregard).
  * Add `reveal_type`. Backport from bpo-46414.
  * Runtime support for PEP 681 and `typing_extensions.dataclass_transform`.
  * `Annotated` can now wrap `ClassVar` and `Final`. Backport from
    bpo-46491. Patch by Gregory Beauregard (@GBeauregard).
  * Add missed `Required` and `NotRequired` to `__all__`. Patch by
    Yuri Karabas (@uriyyo).
  * The `@final` decorator now sets the `__final__` attribute on the
    decorated object to allow runtime introspection. Backport from
    bpo-46342.
  * Add `is_typeddict`. Patch by Chris Moradi (@chrismoradi) and James
    Hilton-Balfe (@Gobot1234).
- from version 4.0.1
  * Fix broken sdist in release 4.0.0. Patch by Adam Turner (@AA-Turner).
  * Fix equality comparison for `Required` and `NotRequired`. Patch by
    Jelle Zijlstra (@jellezijlstra).
  * Fix usage of `Self` as a type argument. Patch by Chris Wesseling
    (@CharString) and James Hilton-Balfe (@Gobot1234).
- from version 4.0.0
  * Starting with version 4.0.0, typing_extensions uses Semantic Versioning.
    See the README for more information.
  * Dropped support for Python versions 3.5 and older, including Python 2.7.
  * Simplified backports for Python 3.6.0 and newer. Patch by Adam Turner (@AA-Turner).
  * Added in version 4.0.0
    + Runtime support for PEP 673 and `typing_extensions.Self`. Patch by
    James Hilton-Balfe (@Gobot1234).
    + Runtime support for PEP 655 and `typing_extensions.Required` and `NotRequired`.
    Patch by David Foster (@davidfstr).
  * Removed in version 4.0.0
    The following non-exported but non-private names have been removed as they are
    unneeded for supporting Python 3.6 and newer.
    + TypingMeta
    + OLD_GENERICS
    + SUBS_TREE
    + HAVE_ANNOTATED
    + HAVE_PROTOCOLS
    + V_co
    + VT_co
- Switch build system from setuptools to pyproject.toml
- Update BuildRequires from pyproject.toml
- Update execution path for testsuite script
* Sat Nov 13 2021 Dirk Müller <dmueller@suse.com>
- Update to 3.10.0.2:
  * Docs improvements
  * Fixes crash  and _GenericAlias import
  * Support most use cases for PEP 612 with Generic
* Mon Jul 12 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.10.0.0
  * Implement TypeGuard (PEP 649)
  * backport ParamSpecArgs/Kwargs
  * Fixed required/optional keys with old-style TypedDict
  * Bring in protocol’s __init__ behaviour same like in python > 3.8
  * Support PEP 612 in typing_extensions (Python 3)
  * Add OrderedDict to typing_extensions
* Tue Jan 12 2021 Benjamin Greiner <code@bnavigator.de>
- Test in separate multibuild flavor to break depcycles with full
  python stdlib
* Tue Jan 12 2021 Benjamin Greiner <code@bnavigator.de>
- clean requirements specifications for python flavors
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- add transitional typing-extensions provides
* Wed Nov  4 2020 Matej Cepl <mcepl@suse.com>
- Use python_module macro for BuildRequires when available.
* Thu Oct 15 2020 Dirk Mueller <dmueller@suse.com>
- update to version 3.7.4.3:
  * enables PEP 613 Typealias to typing_extensions
  * Fix tests for Python 3.9
* Mon Apr  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 3.7.4.2
  * official support for Python 3.8 and 3.9
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2 available
* Wed Nov  6 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 3.7.4.1:
  + Fix isinstance() with generic protocol subclasses after subscripting
  + Fix tests for non-default interpreters
  + Use environment marker to specify typing dependency
  + Fix unions of protocols on Python 2
* Sun Jul 21 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 3.7.4:
  - No changelog available.
- Drop test-sys-executable.patch, merged upstream.
* Sat Mar  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Rebase the patch to the current git state
* Sat Mar  2 2019 John Vandenberg <jayvdb@gmail.com>
- Add support for Python <3.5, using upstream commit as
  test-sys-executable.patch to fix the tests, replacing custom sed.
- Remove unnecessary buid dependency on pytest and pytest-xdist
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the old tarball
* Thu Feb 28 2019 John Vandenberg <jayvdb@gmail.com>
- Replace test_modules.tar.gz with python-testsuite
- Remove fix_tests.patch which is half fixing test_modules.tar.gz,
  and the other half is replaced with a less brittle sed.
- Remove unnecessary build dependencies
- Update to 3.7.2
  * Pass *args and **kwargs to superclass in Generic.__new__
  * Fix for issue #524
  * Fix typing_extensions to support PEP 560
  * Add annotations to NamedTuple children __new__ constructors
  * Add missing 'NoReturn' to __all__ in typing.py
  * Backport Generic.__new__ fix
  * Fix IO.closed to be property
  * Add Final to typing_extensions
  * Fix instance/subclass checks of functions against runtime protocols
  * Add Literal[...] types to typing_extensions
* Tue Oct 23 2018 Matej Cepl <mcepl@suse.com>
- Initial effort to package typing_extensions-3.6.6
